pigz version 2.3.4
diff --git a/README b/README
index c9b9e71..686dede 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.3.4 (xx Feb 2015) by Mark Adler
+pigz 2.3.4 (1 Oct 2016) by Mark Adler
 
 pigz, which stands for Parallel Implementation of GZip, is a fully functional
 replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index a802541..9679e40 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "January 24, 2015"
+.TH PIGZ 1 "October 1, 2016"
 .SH NAME
 pigz, unpigz \- compress or expand files
 .SH SYNOPSIS
@@ -77,7 +77,9 @@
 or
 .B --independent
 option, so that the blocks can be decompressed
-independently for partial error recovery or for random access.
+independently for partial error recovery or for random access. This also
+inserts an extra empty block to flag independent blocks by prefacing
+each with the nine-byte sequence (in hex): 00 00 FF FF 00 00 00 FF FF.
 .PP
 Decompression can't be parallelized, at least not without specially prepared
 deflate streams for that purpose.  As a result,
@@ -184,7 +186,7 @@
 Provide more verbose output.
 .TP
 .B -V --version
-Show the version of pigz.
+Show the version of pigz. -vV also shows the zlib version.
 .TP
 .B -z --zlib
 Compress to zlib (.zz) instead of gzip format.
@@ -210,4 +212,4 @@
 warranty.  In no event will the author be held liable for any damages
 arising from the use of this software.
 .PP
-Copyright (C) 2007-2015 Mark Adler <madler@alumni.caltech.edu>
+Copyright (C) 2007-2016 Mark Adler <madler@alumni.caltech.edu>
diff --git a/pigz.pdf b/pigz.pdf
index 118b884..9c21079 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.c b/pigz.c
index ce01f8a..a35a645 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2015 Mark Adler
  * Version 2.3.4  xx Feb 2015  Mark Adler
  */
 
 /*
@@ -175,10 +175,15 @@
                        Improve decompression error detection and reporting
    2.3.3  24 Jan 2015  Portability improvements
                        Update copyright years in documentation
-   2.3.4  xx Feb 2015  -
+   2.3.4   1 Oct 2016  Fix an out of bounds access due to invalid LZW input
+                       Add an extra sync marker between independent blocks
+                       Add zlib version for verbose version option (-vV)
+                       Permit named pipes as input (e.g. made by mkfifo())
+                       Fix a bug in -r directory traversal
+                       Add warning for a zip file entry 4 GiB or larger
  */
 
-#define VERSION "pigz 2.3.4x\n"
+#define VERSION "pigz 2.3.4\n"
 
 /* To-do:
     - make source portable for Windows, VMS, etc. (see gzip source code)
@@ -3993,7 +3998,7 @@
             case 'K':  g.form = 2;  g.sufx = ".zip";  break;
             case 'L':
                 fputs(VERSION, stderr);
-                fputs("Copyright (C) 2007-2015 Mark Adler\n", stderr);
+                fputs("Copyright (C) 2007-2016 Mark Adler\n", stderr);
                 fputs("Subject to the terms of the zlib license.\n",
                       stderr);
                 fputs("No warranty is provided or implied.\n", stderr);
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
- * Copyright (C) 2007-2015 Mark Adler
- * Version 2.3.4  xx Feb 2015  Mark Adler
+ * Copyright (C) 2007-2016 Mark Adler
+ * Version 2.3.4  1 Oct 2016  Mark Adler
  */
 